@@ -1,6 +1,6 @@
 /*
  * zippy.c -- Implements Zippy the Pinhead chess player on ICS in XBoard
- * $Id: zippy.c,v 1.56 2000/03/04 01:27:51 mann Exp $
+ * $Id: zippy.c,v 1.58 2000/09/17 23:49:27 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -699,7 +699,8 @@ void ZippyGameEnd(result, resultDetails)
      ChessMove result;
      char *resultDetails;
 {
-    if (appData.zippyAcceptOnly[0] == NULLCHAR) {
+    if (appData.zippyAcceptOnly[0] == NULLCHAR &&
+	appData.zippyGameEnd[0] != NULLCHAR) {
       SendToICS(appData.zippyGameEnd);
       SendToICS("\n");
     }
@@ -849,7 +850,6 @@ int ZippyMatch(buf, i)
 	    (gameMode == IcsPlayingBlack && blackTimeRemaining < 0)) {
 	    SendToICS("abort\n");
 	} else {
-	    SendToICS("decline abort\n");
 	    if (appData.zippyTalk)
 	      SendToICS("say Whoa no!  I am having FUN!!\n");
 	    else
@@ -863,7 +863,6 @@ int ZippyMatch(buf, i)
       if (appData.zippyAdjourn) {
 	SendToICS("adjourn\n");
       } else {
-	SendToICS("decline adjourn\n");
 	if (appData.zippyTalk)
 	  SendToICS("say Whoa no!  I am having FUN playing NOW!!\n");
 	else
